/*
 * Copyright 2013-2014 aquenos GmbH.
 * All rights reserved.
 * 
 * This program and the accompanying materials are made available under the 
 * terms of the Eclipse Public License v1.0 which accompanies this distribution,
 * and is available at http://www.eclipse.org/legal/epl-v10.html.
 */

package com.aquenos.csstudio.archive.json.reader.internal;

import java.text.NumberFormat;

import org.epics.util.time.Timestamp;
import org.epics.vtype.Alarm;
import org.epics.vtype.AlarmSeverity;
import org.epics.vtype.Display;
import org.epics.vtype.Statistics;
import org.epics.vtype.Time;

/**
 * Abstract base class for types implementing averaged samples.
 * 
 * @author Sebastian Marsching
 */
public abstract class AbstractStatistics implements Alarm, Display, Statistics,
        Time {

    private String alarmName;
    private AlarmSeverity alarmSeverity;
    private NumberFormat format;
    private String units;
    private Double lowerAlarmLimit;
    private Double lowerCtrlLimit;
    private Double lowerDisplayLimit;
    private Double lowerWarningLimit;
    private Double upperAlarmLimit;
    private Double upperCtrlLimit;
    private Double upperDisplayLimit;
    private Double upperWarningLimit;
    private Double max;
    private Double min;
    private Integer nSamples;
    private Double stdDev;
    private Integer timeUserTag;
    private Timestamp timestamp;
    private boolean timeValid;

    protected AbstractStatistics(String alarmName, AlarmSeverity alarmSeverity,
            Display display, Double min, Double max, Integer nSamples,
            Double stdDev, Integer timeUserTag, Timestamp timestamp,
            boolean timeValid) {
        super();
        this.alarmName = alarmName;
        this.alarmSeverity = alarmSeverity;
        this.format = display.getFormat();
        this.units = display.getUnits();
        this.lowerAlarmLimit = display.getLowerAlarmLimit();
        this.lowerCtrlLimit = display.getLowerCtrlLimit();
        this.lowerDisplayLimit = display.getLowerDisplayLimit();
        this.lowerWarningLimit = display.getLowerWarningLimit();
        this.upperAlarmLimit = display.getUpperAlarmLimit();
        this.upperCtrlLimit = display.getUpperCtrlLimit();
        this.upperDisplayLimit = display.getUpperDisplayLimit();
        this.upperWarningLimit = display.getUpperWarningLimit();
        this.max = max;
        this.min = min;
        this.nSamples = nSamples;
        this.stdDev = stdDev;
        this.timeUserTag = timeUserTag;
        this.timestamp = timestamp;
        this.timeValid = timeValid;
    }

    @Override
    public String getAlarmName() {
        return alarmName;
    }

    @Override
    public AlarmSeverity getAlarmSeverity() {
        return alarmSeverity;
    }

    @Override
    public Integer getTimeUserTag() {
        return timeUserTag;
    }

    @Override
    public Timestamp getTimestamp() {
        return timestamp;
    }

    @Override
    public boolean isTimeValid() {
        return timeValid;
    }

    @Override
    public NumberFormat getFormat() {
        return format;
    }

    @Override
    public Double getLowerAlarmLimit() {
        return lowerAlarmLimit;
    }

    @Override
    public Double getLowerCtrlLimit() {
        return lowerCtrlLimit;
    }

    @Override
    public Double getLowerDisplayLimit() {
        return lowerDisplayLimit;
    }

    @Override
    public Double getLowerWarningLimit() {
        return lowerWarningLimit;
    }

    @Override
    public String getUnits() {
        return units;
    }

    @Override
    public Double getUpperAlarmLimit() {
        return upperAlarmLimit;
    }

    @Override
    public Double getUpperCtrlLimit() {
        return upperCtrlLimit;
    }

    @Override
    public Double getUpperDisplayLimit() {
        return upperDisplayLimit;
    }

    @Override
    public Double getUpperWarningLimit() {
        return upperWarningLimit;
    }

    @Override
    public Double getMax() {
        return max;
    }

    @Override
    public Double getMin() {
        return min;
    }

    @Override
    public Integer getNSamples() {
        return nSamples;
    }

    @Override
    public Double getStdDev() {
        return stdDev;
    }

}
